@@ -59,6 +59,7 @@ use Date::Parse qw(str2time);
 use IPC::Run3;
 use List::SomeUtils qw(uniq any first_value);
 use Path::Tiny;
+use Text::ParseWords qw(shellwords);
 use Unicode::UTF8 qw(encode_utf8 decode_utf8);
 
 const my $EMPTY => q{};
@@ -594,16 +595,6 @@ sub configure_recipe {
       = hc_docdir($compiler, $ENV{CABAL_PACKAGE}, $ENV{CABAL_VERSION});
     my $htmldir = hc_htmldir($compiler, $ENV{CABAL_PACKAGE});
 
-    # DEB_SETUP_GHC_CONFIGURE_ARGS can contain multiple arguments
-    # with their own quoting so run through a shell expansion
-    my $ghc_configure_args = run_quiet(
-        qw{sh -c},
-        'echo -n '
-          . $DOUBLE_QUOTE
-          . ($ENV{DEB_SETUP_GHC_CONFIGURE_ARGS} // $EMPTY)
-          . $DOUBLE_QUOTE
-    );
-
     # the versioned form DEB_SETUP_GHC6_CONFIGURE_ARGS should perhaps be
     # abandoned in favor of the unversioned DEB_SETUP_GHC_CONFIGURE_ARGS
 
@@ -623,8 +614,8 @@ sub configure_recipe {
         "--htmldir=/$htmldir",
         $profiling,
         $ENV{NO_GHCI_FLAG},
-        split($SPACE, $ENV{DEB_SETUP_GHC6_CONFIGURE_ARGS} // $EMPTY),
-        split($SPACE, $ghc_configure_args // $EMPTY),
+        shellwords($ENV{DEB_SETUP_GHC6_CONFIGURE_ARGS} // $EMPTY),
+        shellwords($ENV{DEB_SETUP_GHC_CONFIGURE_ARGS} // $EMPTY),
         split($SPACE, $ENV{OPTIMIZATION} // $EMPTY),
         split($SPACE, $ENV{TESTS} // $EMPTY));
 
